commanded v0.7.1 Commanded.ProcessManagers.ProcessManager behaviour

Macro and behaviour to define a process manager

Summary

Callbacks

Process manager instance handles the domain event

Is the process manager interested in the given command?

Types

domain_event()
domain_event :: struct
process_manager()
process_manager :: struct
uuid()

Callbacks

handle(process_manager, domain_event)

Process manager instance handles the domain event

interested?(domain_event)
interested?(domain_event) ::
  {:start, uuid} |
  {:continue, uuid} |
  false

Is the process manager interested in the given command?